#! /bin/bash

TMP=/tmp
ARC="`pwd`/$1"
DIR="`basename $ARC .tar.bz2`"
shift

GPGKEY=0D1099BA

mkdir -p $TMP/$DIR
tar -cf - "$@" |tar -xf - -C $TMP/$DIR
tar -cjf $ARC -C $TMP $DIR
rm -fr $TMP/$DIR

if [ "$USER" = "kj" ]
then
    if gpg -u $GPGKEY -b $ARC
    then
        scp $ARC* yanestra@dl.sv.gnu.org:/releases/peng4/
    else
        echo '*****' $ARC is prepared
        exit 0
    fi
fi

mkdir -p ../tarball
mv $ARC* ../tarball
